jQuery.sap.require("sas.fscf.views.estimation.EstimationHelper");
jQuery.sap.require("sas.fscf.views.estimation.EstimationResultsHelper");

sap.ui.jsfragment("sas.fscf.views.estimation.EstimationRuleDialog", {

	createContent: function (controller) {/* jshint -W034 */
		"use strict";                     /* jshint +W034 */

        const EstimationHelper = sas.fscf.views.estimation.EstimationHelper;
        const getText = EstimationHelper.getText;
		const newText = EstimationHelper.newText;
        const SpacerFactory = EstimationHelper.SpacerFactory;
        const NOT_APPLICABLE = getText("rules.estimation.not.applicable.label");
        const NOT_APPLICABLE_ABBREVIATION = getText("rules.estimation.not.applicable.abbreviated.label");

		const newLabel = function (aString, span) {
			const layoutSpan = (span) ? span : "L5 M6 S9";
			return new sas.hc.m.Label({
				text: aString,
				layoutData: new sas.hc.ui.layout.GridData({
					span: layoutSpan,
					linebreakL: true,
					linebreakM: true,
					linebreakS: true,
				} ),
			});
		};

		const getModel = function () {
			return controller.getRuleModel();
		};

		const getRule = function () {
			return getModel().getProperty("/rule");
        };

		const generalContent = [
			newLabel(getText("rules.rulesPage.rules.print.ruleID.txt"), "L3 M6 S9"),
			newText("{/rule/displayId}"),
			newLabel(getText("rules.estimation.rule.type.label"), "L3 M6 S9"),
			newText("{/rule/ruleTypeName}"),
			newLabel(getText("rules.estimation.rule.state.label"), "L3 M6 S9"),
			newText("{/rule/state}"),
			newLabel(getText("rules.estimation.alert.type.label"), "L3 M6 S9"),
            newText({
                text: {
                    path: "/rule",
                    formatter: function (rule) {
                        return (rule.isAlertRule) ? rule.alertType.fullDescription : NOT_APPLICABLE_ABBREVIATION;
                    },
                },
                tooltip: {
                    path: "/rule",
                    formatter: function (rule) {
                        return (rule.isAlertRule) ? "" : NOT_APPLICABLE;
                    },
                },
            } ),
			newLabel(getText("rules.rulesPage.queue.txt"), "L3 M6 S9"),
            newText({
                text: {
                    path: "/rule/queueName",
                    formatter: function (queueName) {
                        return (queueName) ? queueName : NOT_APPLICABLE_ABBREVIATION;
                    },
                },
                tooltip: NOT_APPLICABLE,
            } ),
			newLabel(getText("rules.estimation.transaction.type.label"), "L3 M6 S9"),
            newText("{/rule/transactionTypeQualified}"),
			newLabel(getText("rules.estimation.transaction.scope.label"), "L3 M6 S9"),
            newText("{/rule/transactionScopeQualified}"),
        ];

		const generalContentGrid = new sap.ui.layout.Grid({
			hSpacing: 1,
			vSpacing: 0,
			content: generalContent,
			defaultSpan: "L9 M10 S12",
			position: sap.ui.layout.GridPosition.Center,
		} );

        const entityMap = {
          '&': "&amp;",
          '"': "&quot;",
          '\'': "&apos;",
          '<': "&lt;",
          '>': "&gt;"
        };
        const encodeHTMLEntities = function (str) {
          return str.replace( /[&"'<>]/g, c => entityMap[c] );
        };

        const codeSection = new sas.hc.ui.commons.windowshade.WindowShadeSection((this.sId+"ResultWindowShadeSection"), {
			title: getText("rules.rulesPage.rules.print.code.txt"),
            content: [new sas.hc.m.FormattedText({
                    htmlText: "<pre><code>" + encodeHTMLEntities(getRule().ruleCode) + "</code></pre>",
                } ),
            ],
			collapsed: false,
			maxHeight: "auto",
        } );

        const windowShade = new sas.hc.ui.commons.windowshade.WindowShade((this.sId+"WindowShade"), {
            width: "100%",
            sections: [codeSection],
		} ).addEventDelegate({
			onAfterRendering: function (event) {
				// Not sure why even though resultSection above has its property collapsed set to false, it's shown
				// as collapsed.  So we call openAllSections() to force it to be opened!
				event.srcControl.openAllSections();
			},
		} );

		const emphasizeSectionHeaders = function ($propertiesDialog) {
			$propertiesDialog.find(".sasUiWndSectionHrdTitle").css("font-weight", "bold");
		};

        const propertiesDialog = new sas.hc.m.Dialog({
        	id: this.sId + "EstimationRuleDialog",
			title: "{/rule/name}",
			//icon: Icon.PROPERTIES, // Comment this out for now...until we figure out how to place the icon next to the title, now that it's centered with HC9!
    	    content: [
				generalContentGrid,
				SpacerFactory.verticalSpacer("1rem"),
				windowShade,
			],
			contentHeight: "75%",
        	contentWidth: "55%",
        	resizable: true,
        	draggable: true,
    	    rightButton: EstimationHelper.newCloseButton(),
			beforeOpen: [controller.handleRuleDialogBeforeOpen, controller],
			afterClose: [controller.handleRuleDialogAfterClose, controller],
		} )
			.addStyleClass("cfEstPropsDialog")
			.addEventDelegate({
				// Not sure why the last WindowShadeSection's height is set to 100% by default, which forces the vertical scrollbar
				// to appear due to extra blank space from the section.  Here we programmatically set it to "auto" to get around
				// the problem.
				onAfterRendering: function (event) {
					const $propertiesDialog = event.srcControl.$();
					$propertiesDialog.find(".sasUiWnd").css("height", "auto");
					emphasizeSectionHeaders($propertiesDialog);

					$propertiesDialog.find(".sapMText").each(function () {
						this.style.setProperty("line-height", "1.3rem", "important");
					} );
				},
			} );

        return propertiesDialog;
    },
} );
