// (c) 2014, SAS Institute Inc.

jQuery.sap.declare("sas.hc.ui.commons.banner.BannerHeadingV");
jQuery.sap.require("sas.hc.ui.commons.banner.BannerHeadingVRenderer");
jQuery.sap.require("sas.hc.ui.core.Control");
jQuery.sap.require("sas.hc.ui.core.util.ServicesUtil");
jQuery.sap.require("sas.hc.m.Button");
jQuery.sap.require("sap.ui.Device");
jQuery.sap.require("sap.ui.core.Core");
jQuery.sap.require("sas.hc.ui.core.Core");

/**
 * Is used for creating a banner heading within a page. This is used internally by the BannerV (viya version) and is not
 * for general use.
 *
 * @class
 * @name sas.hc.ui.commons.banner.BannerHeadingV
 * @extends sas.hc.ui.Control
 * @protected
 * @author SAS Institute Inc.
 */
sas.hc.ui.core.Control.extend("sas.hc.ui.commons.banner.BannerHeadingV", /** @lends sas.hc.ui.commons.banner.BannerHeadingV.prototype */ {
    metadata: {

        library: "sas.hc.ui.commons",


        properties: {
            // This an optional property that describes the current module or task.
            "task": {type: "string", group: "Misc", defaultValue: "", deprecated: true},

            /** Optional verb string; used to describe the current application section */
            "verb": {type: "string", group: "Misc", defaultValue: ""},

            /** Use this to suppress the verb and subtext; usually when there's not enough room for everything. */
            "showVerb": {type: "boolean", group: "Misc", defaultValue: "true"},

            // subText should not be defined w/o also a "task/verb"
            "subText": {type: "string", group: "Misc", defaultValue: ""},

            /** This is the main application name */
            "text": {type: "string", group: "Misc", defaultValue: ""}

        },

        aggregations: {

            /** This is the combination app switcher and heading. TODO replace with the real app switcher when available.*/
            "headingAppSwitcher": {type: "sas.hc.m.Button", multiple: false, visibility: "hidden"}
        },

        events : {
            pressAppSwitcherBtn: {}
        }
    },


    rb : sap.ui.getCore().getLibraryResourceBundle("sas.hc.ui.commons"),

    renderer: "sas.hc.ui.commons.banner.BannerHeadingVRenderer"



});

/**
 * Initiailize the component.
 *
 * @override
 *
 */
sas.hc.ui.commons.banner.BannerHeadingV.prototype.init = function () {

    var that = this,
        s;

    // Find the name/verb/subText from the config.  Given an app switcher, use it to find the app name.
    if (sas.applicationSwitcher && sas.config && sas.hc.ui.core.util.ServicesUtil.getServicePlatform() === "PETRICHOR") {
        var sAppId = sas.config.get("appId");
        var fCompare = function(oApp) {
            return oApp.appId === sAppId;
        };

        var oApplication = sas.applicationSwitcher.findApplication ? sas.applicationSwitcher.findApplication(fCompare) : null;

        if (oApplication) {
            if (oApplication.appName) {
                // This code is odd.  Not sure the purpose of the html.  Maybe it has something to with special characters like a copyright symbol.
                s =  $("<div></div>").html(oApplication.appName).text();

                // If there's a label and it's different, we may be able to consider it the verb.
                if (oApplication.label) {
                    var sHtmlText = $("<div></div>").html(oApplication.label).text();
                    if (sHtmlText !== s) {
                        this.setVerb(sHtmlText);
                    }
                }
            } else if (oApplication.label) {

                // If no appName, use label.
                s = $("<div></div>").html(oApplication.label).text();
            }
        } else if (sas && sas.config) {
            // App switcher couldn't find it, use the config.
            s = sas.config.getAppName();
        }
    } else if (sas && sas.config) {
        // No app switcher, use the config.
        s =  sas.config.getAppName();
    }

    this.setProperty("text", s);

    // TODO  call the real app switcher open.  Also create association between appswitcher popup and our button.
    var oHeading = new sas.hc.m.Button({
        id: this.getId() + "-bannerheadingbutton",
        hasPopup: true,
        design: sas.hc.m.Button.Design.LightweightPrimary,
        icon: sas.icons.HC.DISCLOSUREEXPAND,
        press: function() {
            that.firePressAppSwitcherBtn();
        }
    });

    // TODO add style so the menu button will look correct.  It's not a heading anymore.
    oHeading.addStyleClass("sasBannerText");
    oHeading.addStyleClass("sasBannerHeadingV");
    oHeading.addStyleClass("sasSmallBtn");

    this.setAggregation("headingAppSwitcher", oHeading);

    this._updateAppName();

    // We need to rebuild the button string when certain properties change.
    this.attachEvent("_change", this.onPropertyChange, this);


};



/**
 * If any of our properties change, we need to rebuild the string.
 *
 * @method
 * @param oEvent
 */
sas.hc.ui.commons.banner.BannerHeadingV.prototype.onPropertyChange = function(oEvent) {

    this._updateAppName();
};

/**
 * Private helper function to update the appname based on the current properties.
 *
 * @private
 * @return {sas.hc.ui.commons.banner.BannerV}
 */
sas.hc.ui.commons.banner.BannerHeadingV.prototype._updateAppName = function(){

    var s,
        aParts= [];

    // The app text has 3 possible parts: appname, task or verb, subtext. Only appname is required.
    aParts.push(this.getText());

    // Task and verb are the same; but verb takes precedence.
    if (this.getShowVerb()) {
        if (this.getVerb() && this.getVerb().length > 0) {
            aParts.push(this.getVerb());
        } else
        if (this.getTask() && this.getTask().length > 0) {
            aParts.push(this.getTask());
        }

        if (this.getSubText() && this.getSubText().length > 0) {
            aParts.push(this.getSubText());
        }
    }

    if (aParts.length === 1) {
        s = aParts[0];
    } else
    if (aParts.length === 2) {
        s = this.rb.getText("bannerHeading.textAndTask.fmt", [aParts[0], aParts[1]]);
    } else
    if (aParts.length === 3) {
        s = this.rb.getText("bannerHeading.textAndTaskAndSubText.fmt", [aParts[0], aParts[1], aParts[2]]);
    }

    this.getAggregation("headingAppSwitcher").setText(s);
    // Update the page title.
    $("head title").text(s);


};

/**
 * Set the associated control.
 *
 * @param oControl
 * @return {*}
 */
sas.hc.ui.commons.banner.BannerHeadingV.prototype.setOpenAndCloseComponent = function (oControl) {

    if (this.getAggregation("headingAppSwitcher")) {
        this.getAggregation("headingAppSwitcher").setOpenAndCloseComponent(oControl);
    }


};


/**
 * We need to hack the html in order to make the heading truncate.
 *
 * @param oControl
 * @return {*}
 */
sas.hc.ui.commons.banner.BannerHeadingV.prototype.onAfterRendering = function () {
    var that = this;

    setTimeout(function () {
        // In some unit tests, it's not visible.
        var $parent = that.$().parent()[0];
        if ($parent) {
            // The parent is the flexbox item container.
            if ((sap.ui.Device.browser.edge ? $parent.offsetWidth + 1 : $parent.offsetWidth) < $parent.scrollWidth) {
                $("button", that.$()).css("width", "100%");
            } else {
                $("button", that.$()).css("width", "");
            }
        }

    }, 0);
};
