// (c) 2014, SAS Institute Inc.

/**
 * SAS extension of BreadcrumbRenderer for HTML Commons.
 * @name sas.hc.ui.commons.breadcrumb.BreadcrumbRenderer
 */

sap.ui.define(['jquery.sap.global','sap/ui/core/Core','sap/ui/core/IconPool','sap/ui/ux3/NavigationBarRenderer','sas/hc/ui/core/Core','sas/hc/ui/core/Icon','./InteractiveBreadcrumbItem'],
    function(jQuery, sapCore, IconPool, sapNavigationBarRenderer, Core, Icon, InteractiveBreadcrumbItem) {

        /**
         * BreadcrumbRenderer
         * @name sas.hc.ui.commons.breadcrumb.BreadcrumbRenderer
         * @namespace
         * @private
         */

        var BreadcrumbRenderer = {};
        BreadcrumbRenderer._rb = sap.ui.getCore().getLibraryResourceBundle("sas.hc.ui.commons");

        /**
         * Renders the HTML for the given control, using the provided {@link sap.ui.core.RenderManager}.
         *
         * @param {sap.ui.core.RenderManager} oRm the RenderManager that can be used for writing to the Render-Output-Buffer
         * @param {sap.ui.core.Control} oControl an object representation of the control that should be rendered
         */

        BreadcrumbRenderer.render = function(oRm, oControl) {
            "use strict";
            var breadcrumbDiv = this._getHTMLDom(oRm, oControl, true),
                $breadcrumbNavDiv = breadcrumbDiv.find('#' + oControl.getId()),
                $breadcrumbUlDiv = breadcrumbDiv.find('#' + oControl.getId() + "-list"),
                aItems = oControl.getItems();

            this._renderBreadcrumb(oRm, oControl, $breadcrumbNavDiv, $breadcrumbUlDiv, breadcrumbDiv);

            if (!oControl.getAggregation("verticalHistoryList") && aItems.length > 1) {
                this._renderArrowButtons(oRm, oControl, breadcrumbDiv, $breadcrumbUlDiv);
            }

            oRm.write(breadcrumbDiv.html());
        };

        BreadcrumbRenderer._renderBreadcrumb = function(oRm, oControl, $breadcrumbNavDiv, $breadcrumbUlDiv, breadcrumbDiv) {

            $breadcrumbNavDiv.addClass("sasUiBreadcrumb");
            $breadcrumbNavDiv.removeClass("sapUiUx3NavBarUpperCaseText");
            $breadcrumbNavDiv.removeAttr('role'); // S1426119 Removing LandMark
            $breadcrumbUlDiv.addClass("sasUiUx3NavBarList");
            $breadcrumbUlDiv.attr('role', 'list');
            $breadcrumbUlDiv.removeAttr('style');

            var $leftArrowBtnDiv = breadcrumbDiv.find('#' + oControl.getId() + "-ofb"),
                $rightArrowBtnDiv = breadcrumbDiv.find('#' + oControl.getId() + "-off"),
                $overflowBtnDiv = breadcrumbDiv.find('#' + oControl.getId() + "-ofl"),
                aItems = oControl.getItems();

            $leftArrowBtnDiv.remove();
            $rightArrowBtnDiv.remove();
            $overflowBtnDiv.remove();

            if (oControl.getAggregation("verticalHistoryList") && aItems.length > 1) {

                $breadcrumbUlDiv.empty();

                var selectControlsHTML = this._modifyIconInSelect(oRm, oControl, oControl.getAggregation("verticalHistoryList"));
                $breadcrumbUlDiv.append(selectControlsHTML);
            } else {
                this._renderBreadcrumbItems(oRm, oControl, $breadcrumbUlDiv, $breadcrumbNavDiv);
            }
        };

        /**
         *
         * @param oRm
         * @param oSelectControl
         * @returns {*}
         */
        BreadcrumbRenderer._modifyIconInSelect = function (oRm, oControl, oSelectControl) {
            var html= oRm.getHTML(oSelectControl),
                $div = $('<div></div>',{html:html});

            var oIcon = oControl.getModifiedIcon();
            var newIconHtml = oRm.getHTML(oIcon);
            //HTMLCOMMONS-7925 -  when interactive breadcrumb turns to vertical history list then there are two icons(list item icon and down arrow of Select).
            //If we find the <span> then it confuses and pick up the <span> of the list item icon. We need the <span> of down arrow icon.
            $div.find(".sapMSltArrow").replaceWith(newIconHtml);

            return $div.html();
        };

        BreadcrumbRenderer._addSeparatorIcon = function (oRm, oControl, i) {
            var iconClasses = "sapUiUx3NavBarDummyItem sasBreadcrumbNavBarItem", newIconHtml,
                oIcon = new Icon(oControl.getId() + "-sepIcon" + "_" + i, {src: sas.icons.HC.DISCLOSURENEXTBREADCRUMB});

            oIcon.destroyTooltip();
            oIcon.addStyleClass(iconClasses);

            newIconHtml = oRm.getHTML(oIcon);
            oIcon.destroy();

            return newIconHtml;
        };

        BreadcrumbRenderer._renderBreadcrumbItems = function(oRm, oControl, $breadcrumbUlDiv, $breadcrumbNavDiv) {
            "use strict";

            var aItems = oControl.getItems(), needToGetInstances = false, noOfItems, selId, i, oItem, sItemId, isSelected,
                $dummyItemDiv;

            $dummyItemDiv = $breadcrumbUlDiv.find('#'+ oControl.getId() + "-dummyItem");
            $dummyItemDiv.parent().remove();

            noOfItems = aItems.length;
            selId = oControl.getSelectedItem();

            for ( i = 0; i < noOfItems; i++) {
                oItem = needToGetInstances ? sap.ui.getCore().byId(aItems[i]) : aItems[i];
                var $itemDiv = $breadcrumbUlDiv.find('#'+ oItem.getId());

                if (/*oItem instanceof sas.hc.ui.commons.breadcrumb.BreadcrumbItem && */oItem.getVisible()) {
                    sItemId = oItem.getId();
                    isSelected = sItemId === selId;
                    $itemDiv.parent().removeAttr("style");

                    if (i > 0) {
                        $itemDiv.parent().before(this._addSeparatorIcon(oRm, oControl, i));
                    }

                    if (isSelected) {
                        if (oControl._clickable || oControl.getSelectedItemClickable()) {
                            $itemDiv.parent().removeClass("sapUiUx3NavBarItemSel");
                        }
                        if (oControl._selected) {// apply the bounce animation only for newly added item.
                            if(noOfItems > 1) // 'S1358069' apply the bounce animation only for second breadcrumb item onwards
                                $itemDiv.parent().addClass("sasUiBreadcrumbItemSelAnimation");

                            oControl._selected = false;//S1358069
                        }
                    }

                    if (oItem instanceof InteractiveBreadcrumbItem) {
                        var siblingsDropDownDiv = this._getHTMLDom(oRm, oItem.getAggregation("siblingsDropDown"), true);
                        var $div = $("<div></div>");
                        // process $div to whatever you want to before wrapping, after wrapping it doesn't honor it.
                        this._writeInteractiveCrumbAttributes(oControl, $div, oItem, i);
                        $itemDiv.wrap($div);
                        // add whatever to $itemDiv before replaceWith after replace it doesn't honor it.
                        $itemDiv.replaceWith(siblingsDropDownDiv.html());
                        $breadcrumbNavDiv.addClass("sasUiInteractiveBreadcrumb");
                    } else {
                        this._writeCrumbAttributes(oControl, oItem, i, $breadcrumbUlDiv);
                    }
                }
            }
        };

        BreadcrumbRenderer._writeInteractiveCrumbAttributes = function(oControl, $div, oItem, itemIndex) {
            var aItems = oControl.getItems(),
                noOfItems = aItems.length,
                sItemId = oItem.getId(),
                selId = oControl.getSelectedItem(),
                isSelected = sItemId === selId,
                actualLabel;

            $div.attr("id", sItemId).attr("data-sap-ui", sItemId);
            $div.attr('aria-setsize', noOfItems);
            $div.attr('aria-posinset', itemIndex + 1);
            $div.attr('aria-checked', isSelected);

            $div.addClass('sapUiUx3NavBarItem sasUiUx3NavBarItem');
            //for qunit GUIDESINF-1352

            actualLabel = this._addAriaLabel(itemIndex, noOfItems);

            $div.attr('aria-label', actualLabel);
        };

        BreadcrumbRenderer._writeCrumbAttributes = function(oControl, oItem, itemIndex, $breadcrumbUlDiv) {
            var aItems = oControl.getItems(),
                noOfItems = aItems.length,
                sItemId = oItem.getId(),
                selId = oControl.getSelectedItem(),
                isSelected = sItemId === selId,
                actualLabel, $itemDiv = $breadcrumbUlDiv.find('#'+ oItem.getId());

            if (isSelected) {
                $itemDiv.removeAttr("href");
                $itemDiv.removeAttr("role");
            } else {
                $itemDiv.attr('role', 'link');
            }

            $itemDiv.addClass('sasUiUx3NavBarItem');

            actualLabel = this._addAriaLabel(itemIndex, noOfItems);

            $itemDiv.parent().attr('aria-label', actualLabel);
        };

        BreadcrumbRenderer._addAriaLabel = function(itemIndex, noOfItems) {
            var actualLabel;
            if (itemIndex === 0) {
                actualLabel = BreadcrumbRenderer._rb.getText("Breadcrumb.start.label.txt");//S1303365
            } else if (itemIndex === (noOfItems - 1)) {
                actualLabel = BreadcrumbRenderer._rb.getText("Breadcrumb.end.label.txt");
            } else {
                actualLabel = BreadcrumbRenderer._rb.getText("Breadcrumb.label.txt");
            }
            return actualLabel;
        };

        BreadcrumbRenderer._renderArrowButtons = function(oRm, oControl, breadcrumbDiv, $breadcrumbUlDiv) {
            var $leftArrowBtnDiv = breadcrumbDiv.find('#' + oControl.getId() + "-ofb"),
                $rightArrowBtnDiv = breadcrumbDiv.find('#' + oControl.getId() + "-off");

            $leftArrowBtnDiv.removeAttr("title");
            $rightArrowBtnDiv.removeAttr("title");

            var leftArrowBtnDiv = this._getHTMLDom(oRm, oControl.getAggregation("leftScrollButton"), true),
                rightArrowBtnDiv = this._getHTMLDom(oRm, oControl.getAggregation("rightScrollButton"), true),
                $leftArrowBtnDiv = breadcrumbDiv.find('#' + oControl.getId() + "-ofb"),
                $rightArrowBtnDiv = breadcrumbDiv.find('#' + oControl.getId() + "-off");

            $breadcrumbUlDiv.after(rightArrowBtnDiv.html());
            $breadcrumbUlDiv.before(leftArrowBtnDiv.html());
        };

        /**
         * Determine CSS rules that should be sufficient to apply custom styles on this instance of Breadcrumb.
         * Custom styles can be accessed using Control.getCustomStyles().
         * @see {sas.hc.ui.core.Styles}
         *
         * @param {sap.ui.core.Control} oControl an object representation of the control that should be rendered
         * @returns {object} An Object with CSS selector as key and CSS style JSON object as value. E.g.
         * <code>
         * {
         *   #<control-id> .sapUiUx3NavBarItem:{
         *          "color":"rgba(255,1,255,0.5)",
         *          ...
         *       }
         * }
         * </code>
         */
        BreadcrumbRenderer.getCustomCSSRules = function(oControl){
            "use strict";

            var a={}, id="#"+oControl.getId();

            a[id + ' .sapUiUx3NavBarItem'] = oControl.getCustomStyles().getStyles();
            a[id + ' .sasBreadcrumbNavBarItem'] = oControl.getCustomStyles().getStyles();
            a[id+' .sasBreadcrumbNavBarForward .sapMBtnCustomIcon'] = oControl.getCustomStyles().getStyles();
            a[id+' .sasBreadcrumbNavBarBack .sapMBtnCustomIcon'] = oControl.getCustomStyles().getStyles();
            // Following styles are added for S1466966
            a[id+' .sapMSltLabel'] =  oControl.getCustomStyles().getStyles();
            a[' .sasUiBreadcrumbInteractivePopover .sapMSelectListItemBase, .sasUiBreadcrumbInteractivePopover .sapMSelectListItemBase:hover'] = oControl.getCustomStyles().getStyles();

            /*a[id + ' li:not(.sapUiUx3NavBarItemSel) > .sapUiUx3NavBarItem'] = oControl.getCustomStyles().getStyles();
             a[id+' .sapUiUx3NavBarDummyItem']=oControl.getCustomStyles().getStyles();
            */
            return a;
        };

        BreadcrumbRenderer._getHTMLDom = function (oRm, oControl, isParent ) {
            var html;
            if(isParent){
                var myRendererRef = BreadcrumbRenderer.render;
                BreadcrumbRenderer.render = sapNavigationBarRenderer.render;
                html = oRm.getHTML(oControl);
                BreadcrumbRenderer.render = myRendererRef;
            } else {
                html = oRm.getHTML(oControl);
            }

            return $('<div></div>', {html: html});

        };

        return BreadcrumbRenderer;

    }, true);
