/*
 +-------------+----------------------------------------------------------------+
 | PRODUCT:    | SAS Fraud Management
 | FILE:       | export_cpp_list.sas
 | DESCRIPTION:| Create CPP list .csv file
 +------------------------------------------------------------------------------+
 | USAGE:      | Included by fsmrh_cpp_reports.sas
 +------------------------------------------------------------------------------+
 | COMMENTS:   | 
 +-------------+----------------------------------------------------------------+
 */

/*-------------------------------------------------------------------
 * Copyright (c) 2014 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

   data _null_;
     retain BK -1;
      set  &indata  end=EFIEOD;
      %let _EFIERR_ = 0;     /* set the ERROR detection macro variable */
      %let _EFIREC_ = 0;     /* clear export record count macro variable */
      file "&cpp_list_file" delimiter=',' DSD DROPOVER lrecl=32767;

         format ent_comp_start_dt date9. ;
         format ent_comp_end_dt date9. ;
         format ent_type $4. ;
         format ent_id $4. ;
         format ent_id_long $&max_ent_id_long_len..;
         format 
				ent_numcards_A
				ent_numcards_C
				ent_numcards_D
				ent_numcards_E         
         15. 
         ;
         format ent_numtrnx 15. ;
         format 
				ent_frdrate_A
				ent_frdrate_C
				ent_frdrate_D
				ent_frdrate_E
         best12. 
         ;
         format            
         	ent_frdday_p10 4.
           	ent_frdday_p25 4.
           	ent_frdday_p50 4.
           	ent_frdday_p75 4.
           	ent_frdday_p90 4.
           	;
      if _n_ = 1 then        /* write column names */
       do;
         put
         'ent_comp_start_dt'
         ','
         'ent_comp_end_dt'
         ','
         'ent_type'
         ','
         'ent_id_long'
         ','
         'ent_id'
         ','
			'ent_numcards_A'
			','
			'ent_numcards_C'
			','
			'ent_numcards_D'
			','
			'ent_numcards_E'         
         ','
         'ent_numtrnx'
         ','
			'ent_frdrate_A'
         ','
			'ent_frdrate_C'
         ','
			'ent_frdrate_D'
         ','
			'ent_frdrate_E'
         ','
         'ent_frdday_p10'
         ','
         'ent_frdday_p25'
         ','
         'ent_frdday_p50'
         ','
         'ent_frdday_p75'
         ','
         'ent_frdday_p90'
         ;
       end;
       do;
         EFIOUT + 1;
         put ent_comp_start_dt @;
         put ent_comp_end_dt @;
         put ent_type $  @;
         put ent_id_long $  @;
         put ent_id $  @;

			put
				ent_numcards_A
				ent_numcards_C
				ent_numcards_D
				ent_numcards_E @;
				
         put ent_numtrnx @;
         put
				ent_frdrate_A
				ent_frdrate_C
				ent_frdrate_D
				ent_frdrate_E @;

         put 
				ent_frdday_p10 
				ent_frdday_p25 
				ent_frdday_p50 
				ent_frdday_p75 
				ent_frdday_p90 
         ;
       end;
      if _ERROR_ then call symputx('_EFIERR_',1);  /* set ERROR detection macro variable */
      if EFIEOD then call symputx('_EFIREC_',EFIOUT);
    run;